#' Generate predicted probabilities from a model to plot CIs
#' 
#' @param mod Model object, for example as generated by lmer()
#' @param tmpdat A data.frame containing data to be used to generate predicted values
#' @param column A character with the name of the column containing the response variable (must match one of the columnames in tmpdat)
#' @param jvalues A vector containing the sequence of numbers in the predictor variable to be used in prediction
#' @examples 
#' \dontrun{
#' dat <- data.frame(subject=sample(c("M","F"),size = 50,replace = TRUE),
#'                   size=rnorm(50,mean=19,sd=0.5),
#'                   dur=rnorm(50))
#' mod1<-lm(dat$dur~dat$size*dat$subject)
#' subset<-dat[dat$subject=="F",]
#' jvalues<- seq(from=min(dat$size), to=max(dat$size), length.out=100)
#' fpredict<- predicted_probs(mod1, subset,"dur", jvalues)
#' }

predicted_probs<-function(mod, tmpdat,column, jvalues){
  # calculate predicted probabilities and store in a list
  pp <- lapply(jvalues, function(j) {
    
    tmpdat[,column] <- j
    p<-predict(mod, newdata = tmpdat, type = "response")
    
    return(p)
  })
  
  # get the means with lower and upper quartiles
  plotdat <- t(sapply(pp, function(x) {
    
    c(M = mean(x), quantile(x, c(0.2, 0.8)))
  }))
  
  # add in LengthofStay values and convert to data frame
  plotdat <- as.data.frame(cbind(plotdat, jvalues))
  
  # better names and show the first few rows
  colnames(plotdat) <- c("PredictedProbability", "Lower", "Upper", "Variable")
  
  return(plotdat)
}


